Welcome to ClientVPS Mirrors

Help for package roundyh
Type: Package
Title: Round Dataframe
Version: 0.1.0
Description: A simple rounding function. The default round() function in R uses the IEC 60559 standard and therefore it rounds 0.5 to 0 and rounds -1.5 to -2. The roundx() function accounts for this and helps to round 0.5 up to 1.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.2.3
Suggests: spelling, testthat (≥ 3.0.0)
Config/testthat/edition: 3
Language: en-US
Depends: R (≥ 3.5.0)
NeedsCompilation: no
Packaged: 2023-04-06 16:58:11 UTC; sse
Author: Duan Yuanheng [aut, cre, cph]
Maintainer: Duan Yuanheng <yhyuanheng@gmail.com>
Repository: CRAN
Date/Publication: 2023-04-07 09:00:02 UTC

A rounding function

Description

A rounding function

Usage

roundx(n, dp)

Arguments

n

a number to round

dp

decimal place to round to

Value

rounded number

Examples

roundx(10.111, 1)

Applying the rounding function to all numeric values of dataframe while excluding characters

Description

Applying the rounding function to all numeric values of dataframe while excluding characters

Usage

roundx_df(df, dp)

Arguments

df

a dataframe

dp

decimal place to round to

Value

a dataframe

Examples

roundx_df(data.frame(c(1.111, 1, 1.11), c(1, 1, 1), c("a", "b", "c")), 1)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.